.. _ext-api:

**********************************
:mod:`mopidy.ext` -- Extension API
**********************************

If you want to learn how to make Mopidy extensions, read :ref:`extensiondev`.

.. automodule:: mopidy.ext
    :synopsis: Extension API for extending Mopidy
    :members:
